pub struct LifecycleLauncher { /* private fields */ }Expand description
Production implementation of e1’s launcher port.
Implementations
Sourceimpl LifecycleLauncher
impl LifecycleLauncher
pub fn new( host_id: HostId, app_paths: AppPaths, diagnostics_root: impl Into<PathBuf>, runner_group_id: u64, timeouts: RecoveryTimeouts, retry: RetryPolicy, ports: LifecyclePorts, ) -> Self
Sourcepub async fn recover_startup(
&self,
policies: &[ScalePolicy],
) -> Result<Vec<ReplacementIntent>, LifecycleError>
pub async fn recover_startup( &self, policies: &[ScalePolicy], ) -> Result<Vec<ReplacementIntent>, LifecycleError>
Reconcile the entire journal before allowing a launch. Unknown-policy attempts are left untouched rather than being acted on without an ownership proof.
Sourcepub async fn supervise(
&self,
policy: &ScalePolicy,
) -> Result<Vec<ReplacementIntent>, LifecycleError>
pub async fn supervise( &self, policy: &ScalePolicy, ) -> Result<Vec<ReplacementIntent>, LifecycleError>
Supervise all attempts of one policy during an ordinary poll.