pub struct ReplacementIntent {
pub policy: PolicyId,
pub previous_attempt: AttemptId,
pub operation: &'static str,
}Expand description
A lifecycle conclusion that must return through ordinary demand and capacity allocation before another runner may start.
Fields
policy: PolicyIdprevious_attempt: AttemptIdoperation: &'static strTrait Implementations
Sourceimpl Clone for ReplacementIntent
impl Clone for ReplacementIntent
Sourcefn clone(&self) -> ReplacementIntent
fn clone(&self) -> ReplacementIntent
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for ReplacementIntent
Sourceimpl Debug for ReplacementIntent
impl Debug for ReplacementIntent
impl Eq for ReplacementIntent
Sourceimpl PartialEq for ReplacementIntent
impl PartialEq for ReplacementIntent
impl StructuralPartialEq for ReplacementIntent